const express = require("express");
const { ApolloServer, gql } = require("apollo-server-express");
const { buildClientSchema, printSchema } = require("graphql/utilities");
const { makeExecutableSchema } = require("graphql-tools");
const fs = require("fs");

let schemaJSON;
try {
  schemaJSON = JSON.parse(fs.readFileSync("src/server-schema.json", "UTF-8"));
} catch (e) {
  if (e.code === "ENOENT") {
    console.log(`File src/server-schema.json is missing.

Try filling it with the schema of the server running in production.`);
  } else {
    console.error(e);
  }
  process.exit(1);
}

const schemaTXT = printSchema(buildClientSchema(schemaJSON.data));
const typeDefs = gql(schemaTXT);

const resolvers = {
  FIXME: () => ({
    FIXME: () => "FIXME",
  }),
};

const server = new ApolloServer({
  typeDefs,
  mocks: resolvers,
  playground: {},
});

const app = express();
server.applyMiddleware({ app });

const port = 5000;
app.listen({ port }, () => {
  console.log(`Listening on http://localhost:${port}${server.graphqlPath}

Now try using the UI and making queries.
How to add custom overrides to the "resolvers" object?`);
});
